@@ -834,6 +834,49 @@ class tree:
         #param
         return centerlines_all,polys
 
+    def export_centerlines(self,outdir=None,folder="centerlines_tmp",num_points=100):
+        _,_,interp_xyzr = self.export(make=False)
+
+        if outdir is None:
+            outdir = os.getcwd()
+        outdir = outdir + os.sep + folder
+
+        if not os.path.exists(outdir):
+            os.mkdir(outdir)
+
+        def make_points(x,y,z):
+            """Helper to make XYZ points"""
+            return np.column_stack((x, y, z))
+
+        def lines_from_points(points):
+            """Given an array of points, make a line set"""
+            poly = pv.PolyData()
+            poly.points = points
+            cells = np.full((len(points) - 1, 3), 2, dtype=np.int_)
+            cells[:, 1] = np.arange(0, len(points) - 1, dtype=np.int_)
+            cells[:, 2] = np.arange(1, len(points), dtype=np.int_)
+            poly.lines = cells
+            return poly
+
+        polys = []
+        for ind,spline in enumerate(interp_xyzr):
+            n = np.linspace(0,1,num_points)
+            spline_data = splev(n,spline[0])
+            spline_data_normal = splev(n,spline[0],der=1)
+            points = make_points(spline_data[0],spline_data[1],spline_data[2])
+            normal = make_points(spline_data_normal[0],spline_data_normal[1],spline_data_normal[2])
+            normal = normal/np.linalg.norm(normal,axis=1).reshape(-1,1)
+            poly_line = lines_from_points(points)
+            #poly_line['VesselId'] = np.ones(num_points,dtype=int)*ind
+            poly_line['MaximumInscribedSphereRadius'] = spline_data[3]
+            #poly_line['CenterlineSectionArea'] = np.pi*spline_data[3]**2
+            #poly_line.point_data.set_array(normal,'CenterlineSectionNormal')
+            polys.append(poly_line)
+
+        for ind,poly in enumerate(polys):
+            poly.save(outdir+os.sep+"centerline_id_{}.vtp".format(ind))
+        return polys
+
     def collision_free(self,outside_vessels,radius_buffer=0.01):
         return no_outside_collision(self,outside_vessels,radius_buffer=radius_buffer)
 
